@@ -1,24 +1,22 @@
-from ..base.base import Parser
+from ...provider_api.weibo import MediaType, WeiboAPI
 from ...types import (
+    Ani,
+    Image,
+    ImageParseResult,
     MultimediaParseResult,
     Video,
-    Image,
-    Ani,
     VideoParseResult,
-    ImageParseResult,
 )
-from ...utiles.weibo_api import WeiboAPI, MediaType
+from ..base.base import BaseParser
 
 
-class WeiboParser(Parser):
+class WeiboParser(BaseParser):
     __platform_id__ = "weibo"
     __platform__ = "微博"
     __supported_type__ = ["视频", "图文"]
     __match__ = r"^(http(s)?://)(m\.|)weibo.(com|cn)/(?!(u/)).+"
 
-    async def parse(
-        self, url: str
-    ) -> MultimediaParseResult | VideoParseResult | ImageParseResult:
+    async def parse(self, url: str) -> MultimediaParseResult | VideoParseResult | ImageParseResult:
         url = await self.get_raw_url(url)
 
         weibo = await WeiboAPI(self.cfg.proxy).parse(url)
